Calculates API
==============

.. autofunction:: calculates.simplify

.. autofunction:: calculates.distance

.. autofunction:: calculates.euclidean_distance

.. autofunction:: calculates.hausdorff_distance

.. autofunction:: calculates.frechet_distance

.. autofunction:: calculates.spatial_assembling_distance

.. autofunction:: calculates.lcss_distance

.. autoclass:: _algorithms.Algorithms
